Structs
- Binary
Span - Cloned from the crate
nom_locatebut with the omission of computing the line & column number since we don’t care about them in binary protocols, and they do make using theLocateSpanslower.
nom_locate but with the omission of computing
the line & column number since we don’t care about them in binary protocols,
and they do make using the LocateSpan slower.